# GINsim-python

[![PyPI version](https://badge.fury.io/py/ginsim.svg)](https://badge.fury.io/py/ginsim)

Python gateway and integration into the Jupyter notebook for GINsim and bioLQM

## Installation

### With conda

```
conda install -c colomoto ginsim-python
```

### With pip

```
pip install ginsim
python -m ginsim_setup
```

